@@ -334,8 +334,8 @@ class JsonList(list):
                 val = float(val)
             check_type(val, self.list_type, "Wrong type %s, this list can hold only instances of %s" % (type(val), str(self.list_type)))
         else:
-            if not (issubclass(type(val), JsonObject) or isinstance(val, (str, int, float, bool, JsonList))):
-                raise TypeError("Wrong type %s, this list can hold only str, int, float, bool, JsonObject or JsonList" % (type(val),))
+            if not (issubclass(type(val), JsonObject) or isinstance(val, (str, int, float, bool, datetime, JsonList))):
+                raise TypeError("Wrong type %s, this list can hold only str, int, float, bool, datetime, JsonObject or JsonList" % (type(val),))
 
     def __iadd__(self, other):
         map(self._typeCheck, other)
@@ -433,11 +433,11 @@ class JsonList(list):
                 return ix
         raise RuntimeError("Value not found")
 
-    def find_ordered(self, value, key=None, search_type=SearchType.Exact):
-        return self[self.find_ordered_index(value, key=key, search_type=search_type)]
+    def find_ordered(self, value, key=None, search_type=SearchType.Exact, order=SortOrder.Ascending):
+        return self[self.find_ordered_index(value, key=key, search_type=search_type, order=order)]
 
-    def find_ordered_index(self, value, key=None, search_type=SearchType.Exact):
-        i = bin_search(self, value, key=key, search_type=search_type)
+    def find_ordered_index(self, value, key=None, search_type=SearchType.Exact, order=SortOrder.Ascending):
+        i = bin_search(self, value, key=key, search_type=search_type, order=order)
         return i
 
     def process(self, l):
@@ -469,6 +469,10 @@ class JsonList(list):
                 new_list.append(it.parse(json_dictionary=i))
             elif issubclass(ic, JsonList):
                 new_list.append(it.parse(json_list=i))
+            elif issubclass(ic, datetime):
+                new_list.append(datetime.strptime(i, JsonDate.date_format))
+            elif issubclass(ic, JsonString):
+                new_list.append(JsonString(i))
             else:
                 new_list.append(i)
         return new_list
